@@ -166,3 +166,12 @@ plot_recmap <- function(S, col='#00000011', col.text = 'grey', ...){
 }
 
 
+.onAttach <- function(lib, pkg){
+	if(interactive()){
+		version <- packageVersion('recmap')
+		packageStartupMessage("Package 'recmap' version ", version)
+		# packageStartupMessage("Type 'citation(\"recmap\")' for citing this R package in publications.")
+	  invisible()
+	}
+
+}
